%global url_ver %%(echo %{version} | cut -d. -f1)

Summary:       Window management and application launching for GNOME
Name:          gnome-shell
Version:       44.5
Release:       1%{?dist}
License:       GPLv2+
URL:           https://wiki.gnome.org/Projects/GnomeShell
Source0:       https://download.gnome.org/sources/gnome-shell/%{url_ver}/%{name}-%{version}.tar.xz

Patch3000:     gnome-shell-favourite-apps-firefox.patch
Patch3001:     0001-gdm-Work-around-failing-fingerprint-auth.patch

BuildRequires: bash-completion gcc meson git pkgconfig(ibus-1.0) desktop-file-utils
BuildRequires: pkgconfig(libedataserver-1.2) pkgconfig(gcr-4) pkgconfig(gjs-1.0)
BuildRequires: pkgconfig(gio-2.0) pkgconfig(gnome-autoar-0) pkgconfig(gnome-desktop-4)
BuildRequires: pkgconfig(gobject-introspection-1.0) mesa-libGL-devel mesa-libEGL-devel
BuildRequires: pkgconfig(libnm) pkgconfig(polkit-agent-1) pkgconfig(libstartup-notification-1.0)
BuildRequires: pkgconfig(libsystemd) pkgconfig(gstreamer-base-1.0) pkgconfig(libpipewire-0.3)
BuildRequires: pkgconfig(gdk-x11-3.0) pkgconfig(gtk4) gettext python3  libXfixes-devel  librsvg2-devel
BuildRequires: mutter-devel pkgconfig(libpulse) gnome-bluetooth-libs-devel

Requires:      gnome-bluetooth gnome-desktop3 gcr gobject-introspection gjs gtk3 gtk4
Requires:      libadwaita highcontrast-icon-theme libnma librsvg2 mutter upower polkit
Requires:      gnome-desktop3 glib2 gsettings-desktop-schemas gnome-settings-daemon gstreamer1
Requires:      gstreamer1-plugins-good pipewire-gstreamer xdg-user-dirs-gtk at-spi2-atk ibus
Requires:      libgnomekbd accountsservice-libs gdm-libs gnome-control-center python3
Requires:      switcheroo-control geoclue2-libs libgweather4 bolt xdg-desktop-portal-gtk

Recommends:    gnome-session-xsession gnome-tour

Provides:      desktop-notification-daemon = %{version}-%{release}
Provides:      PolicyKit-authentication-agent = %{version}-%{release}
Provides:      bundled(gvc)
Provides:      bundled(libcroco) = 0.6.13

%description
GNOME Shell provides core user interface functions for the GNOME 3 desktop, like switching to windows and
launching applications. GNOME Shell takes advantage of the capabilities of modern graphics hardware and
introduces innovative user interface concepts to provide a visually attractive and easy to use experience.

%prep
%autosetup -S git -n %{name}-%{version}

%build
%meson -Dextensions_app=false
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_datadir}/gnome-shell/extensions
mkdir -p %{buildroot}%{_datadir}/gnome-shell/search-providers

%find_lang %{name}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Shell.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Shell.Extensions.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Shell.PortalHelper.desktop

%files -f %{name}.lang
%license COPYING
%doc README.md
%{_bindir}/gnome-shell
%{_bindir}/gnome-extensions
%{_bindir}/gnome-shell-extension-prefs
%{_bindir}/gnome-shell-extension-tool
%{_bindir}/gnome-shell-perf-tool
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/glib-2.0/schemas/00_org.gnome.shell.gschema.override
%{_datadir}/applications/org.gnome.Shell.Extensions.desktop
%{_datadir}/applications/org.gnome.Shell.desktop
%{_datadir}/applications/org.gnome.Shell.PortalHelper.desktop
%{_datadir}/bash-completion/completions/gnome-extensions
%{_datadir}/gnome-control-center/keybindings/50-gnome-shell-launchers.xml
%{_datadir}/gnome-control-center/keybindings/50-gnome-shell-screenshots.xml
%{_datadir}/gnome-control-center/keybindings/50-gnome-shell-system.xml
%{_datadir}/gnome-shell/
%{_datadir}/dbus-1/services/org.gnome.ScreenSaver.service
%{_datadir}/dbus-1/services/org.gnome.Shell.CalendarServer.service
%{_datadir}/dbus-1/services/org.gnome.Shell.Extensions.service
%{_datadir}/dbus-1/services/org.gnome.Shell.HotplugSniffer.service
%{_datadir}/dbus-1/services/org.gnome.Shell.Notifications.service
%{_datadir}/dbus-1/services/org.gnome.Shell.PortalHelper.service
%{_datadir}/dbus-1/services/org.gnome.Shell.Screencast.service
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Extensions.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Introspect.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.PadOsd.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Screencast.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Screenshot.xml
%{_datadir}/dbus-1/interfaces/org.gnome.ShellSearchProvider.xml
%{_datadir}/dbus-1/interfaces/org.gnome.ShellSearchProvider2.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Shell.Extensions.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Shell.Extensions-symbolic.svg
%dir %{_datadir}/xdg-desktop-portal/portals/
%{_datadir}/xdg-desktop-portal/portals/gnome-shell.portal
%{_userunitdir}/org.gnome.Shell-disable-extensions.service
%{_userunitdir}/org.gnome.Shell.target
%{_userunitdir}/org.gnome.Shell@wayland.service
%{_userunitdir}/org.gnome.Shell@x11.service
%{_libdir}/gnome-shell/
%{_libexecdir}/gnome-shell-calendar-server
%{_libexecdir}/gnome-shell-perf-helper
%{_libexecdir}/gnome-shell-hotplug-sniffer
%{_libexecdir}/gnome-shell-portal-helper
%{_mandir}/man1/gnome-extensions.1*
%{_mandir}/man1/gnome-shell.1*

%changelog
* Fri Oct 20 2023 Wang Guodong <gordonwwang@tencent.com> - 44.5-1
- Upgrade to 44.5
- fix CVE-2023-43090

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 44.3-4
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 24 2023 Miaojun Dong <zoedong@tencent.com> - 44.3-3
- Rebuild for gcr-4.1.0

* Wed Aug 23 2023 Miaojun Dong <zoedong@tencent.com> - 44.3-2
- Rebuild for at-spi2-core-2.49.90

* Tue Aug 22 2023 Shuo Wang <abushwang@tencent.com> - 44.3-1
- update to 44.3

* Fri Aug 18 2023 Wang Guodong <gordonwwang@tencent.com> - 43.1-4
- Rebuilt for librsvg2 2.56.90

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.1-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Dec 9 2022 Shuo Wang <abushwang@tencent.com> - 43.1-1
- initial build

